ACPsymbolique <- function(data.sym, Y.sym, x1=1, x2=2){   
  # data.sym = dataX.sym
  # Y.sym = dataY.sym
  # PRE-REQUIS
  library(RSDA)
  par(mfrow=c(2, 2))
  res <- list()  
  namesvar   <- data.sym$sym.var.names
  namesvarY  <- Y.sym$sym.var.names
  namesvarYX <- c(namesvarY,namesvar)
  # ACP
  CorrX      <- CorCovSymbJenn(data.sym)$corr
  pc         <- eigen(CorrX)
  res$pcvar  <- pc$values   # valeurs propres
  res$pcload <- pc$vectors  # vecteurs propres
  # INERTIE DES COMPOSANTES
  res$per.var <-  res$pcvar/sum(res$pcvar)*100
  barplot(res$per.var, main="Inertie des composantes", xlab="Composantes", ylab="% d'inertie")
  #REPRESENTATION DES INDIVIDUS SOUS FORME DE POLYTOPES ET RECTANGLES
  #CONSTRUCTION DE LA MATRICE DES SOMMETS  
  data <- as.matrix(data.sym$data)
  p    <- data.sym$M    # nombre de variables
  m    <- data.sym$N	# nombre d'observations
  #CALCUL DES MOYENNES
  ybaru <- matrix(0, m, p)
  for (u in 1:m){
    for (j in 1:p){ 
      ybaru[u,j] = (data[u,2*j-1] + data[u,2*j])/2
    }
  }
  ybar <- c(rep(0,p))	
  for (j in 1:p){
    ybar[j] = sum(ybaru[,j])/m
  }  
  # CALCUL DE LA MATRICE DES SOMMETS
  CovYX <- CorCovSymbJenn(data.sym)$cov
  Z     <- matrix(0, m, 2*p)
  for (i in 1:m){
    for (j in 1:p){
      Z[i,2*j-1] = (data[i,2*j-1]-ybar[j])/(sqrt(CovYX[j,j]))
      Z[i,2*j] = (data[i,2*j]-ybar[j])/(sqrt(CovYX[j,j]))
    }
  } 
  Zvert <- matrix(0, m*(2^p), p)  
  for (i in 1:m){
    for (j in 1:p){
      for (k in 1:2^(p-j)){
        Zvert[((i-1)*2^p)+k, j] = Z[i,2*j-1]
        Zvert[((i-1)*2^p)+2^(p-j)+k, j] = Z[i,2*j]
      }
    }
  }
  for (l in 2:p){
    for (i in 1:m){
      for (j in l:p){
        for (k in 1:2^(p-j+l-1)){
          Zvert[((i-1)*2^p)+(2^(p-j+l-1))+k, j] = Zvert[((i-1)*2^p)+k, j]
        }
      }
    }
  } 
  #PROJECTION DES SOMMETS DANS LE NOUVEL ESPACE FACTORIEL
  res$scores <- Zvert %*% res$pcload
  #CONSTRUCTION DE LA MATRICE DE CONNEXION 'CNV' 
  #  REPRESENTATION DES INDIVIDUS PAR LES POLYTOPES
  nv  <- 2^p
  cnv <- matrix(rep(0,p*nv), nv)  
  for (j in 1:p){
    for (k in 0:(2^(j-1)-1)){
      for (i in (1+(2^(p-j+1))*k):(2^(p-j)+(2^(p-j+1))*k)){
        cnv[i,j] = i + 2^(p-j)
      }
      for (i in (1+2^(p-j)+(2^(p-j+1))*k):(2^(p-j+1)+(2^(p-j+1))*k)){
        cnv[i,j] = i - 2^(p-j)
      }
    }
  }
  cnv <- cbind(1:nv, cnv)
  #Graphiques des individus sur le plan factoriel par les polytopes
  plot(res$scores[, x1:x2], type='n', xlab=paste("Composante ", x1, " (", round(res$per.var[x1], 1), "%)", sep=""), 
       ylab=paste("Composante ", x2, " (", round(res$per.var[x2], 1), "%)", sep=""), main="Plan factoriel (polytopes)")  
  abline(h=0, v=0)
  for (i in 1:m){
    x <- res$scores[((i-1)*2^p+1):(i*2^p), c(x1,x2)]
    for (v in 1:nv){
      for (j in 1:p){  
        lines(x[cnv[v, c(1, j+1)],], lwd=0.5, col=i+1)
      }
    }    
  }  
  # REPRESENTATION DES INDIVIDUS SOUS FORME DE RECTANGLES MCAR
  namesobj <- data.sym$sym.obj.names
  plot(res$scores[, x1:x2], type='n', xlab=paste("Composante ", x1, " (", round(res$per.var[x1], 1), "%)", sep=""), 
       ylab=paste("Composante ", x2, " (", round(res$per.var[x2], 1), "%)", sep=""), main="Plan factoriel (MCAR)")  
  abline(h=0, v=0)
  for (i in 1:m){
    x     <- res$scores[((i-1)*2^p+1):(i*2^p), c(x1,x2)]    
    xmin1 <- min(x[, 1])
    xmax1 <- max(x[, 1])
    ymin2 <- min(x[, 2])
    ymax2 <- max(x[, 2])    
    points(xmin1, ymin2, type='p', pch=i+1, col=i+1, lwd=1)
    points(xmin1, ymax2, type='p', pch=i+1, col=i+1, lwd=1)
    points(xmax1, ymin2, type='p', pch=i+1, col=i+1, lwd=1)
    points(xmax1, ymax2, type='p', pch=i+1, col=i+1, lwd=1)
    rect(xmin1, ymin2, xmax1, ymax2, lwd=1, border=i+1)  
    text(xmax1-0.1, ymin2-0.1, labels=namesobj[i], col=i+1,cex=0.7) 
  } 
  #LES 4 PREMIERES COMPOSANTES PRINCIPALES SOUS LA FORME D'INTERVALLES (OBJET RSDA)
  CP1    <- matrix(0, m, 2)
  CP2    <- matrix(0, m, 2)
  CP3    <- matrix(0, m, 2)
  CP4    <- matrix(0, m, 2)
  colint <- matrix("$I", m, 1)
  
  for (i in 1:m){
    x <- res$scores[((i-1)*2^p+1):(i*2^p), c(1:4)]
    CP1[i, 1] <- min(x[, 1])
    CP1[i, 2] <- max(x[, 1])
    CP2[i, 1] <- min(x[, 2])
    CP2[i, 2] <- max(x[, 2])
    CP3[i, 1] <- min(x[, 3])
    CP3[i, 2] <- max(x[, 3])
    CP4[i, 1] <- min(x[, 4])
    CP4[i, 2] <- max(x[, 4])    
  } 
  res$CPint<- cbind(colint, CP1, colint, CP2, colint, CP3, colint, CP4)
  colnames(res$CPint) <- c("$I", "CP1", "CP1", "$I", "CP2", "CP2", "$I", "CP3", "CP3", "$I", "CP4", "CP4")
  # REPRESENTATION DES VARIABLES DANS LE CERCLE DES CORRELATIONS DU PLAN (X1, X2)
  #REGROUPEMENT DE Y, X ET CP (OBJET RSDA) EN PRENANT X ET Y SOUS LA FORME 'META'
  Y       <- Y.sym$meta
  X       <- data.sym$meta
  YXCP    <- cbind(Y, X, res$CPint)
  write.table(YXCP, "YXCP.csv", dec=".", sep=";", row.names=FALSE)
  YXCP.sym <- read.sym.table("YXCP.csv", header=TRUE, sep=";",dec=".",row.names=NULL)
  # CORRELATIONS ENTRE Y, X ET CP
  CorYXCP           <- CorCovSymbJenn(YXCP.sym)$cor
  namesvarYXCP      <- c(namesvarYX, "CP1", "CP2", "CP3", "CP4") 
  colnames(CorYXCP) <- rownames(CorYXCP)
  # CERCLE DES CORRELATIONS AVEC Y COMME VARIABLE SUPPLEMENTAIRE   
  a <- seq(0, 2*pi, length=100)
  # plot(cos(a), sin(a), type='l', lty=3, xlab=paste("Composante ", x1, " (", round(res$per.var[x1], 1), "%)", sep=""), 
  #     ylab=paste("Composante ", x2, " (", round(res$per.var[x2], 1), "%)", sep=""), main="Cercle des corrélations sur CP int")
  plot(cos(a), sin(a), type='l', lty=3, xlab=paste("Composante ", x1, " (", round(res$per.var[x1], 1), "%)", sep=""), 
       ylab=paste("Composante ", x2, " (", round(res$per.var[x2], 1), "%)", sep=""))
  abline(h=0, v=0)
  vX <- CorYXCP[c(p+1+x1, p+1+x2), 2:(p+1)]
  vY <- CorYXCP[c(p+1+x1, p+1+x2), 1, drop=F]
  arrows(0, 0, vX[1, ], vX[2, ], lwd=0.7)
  text(vX[1,], vX[2,] , labels=namesvar, cex=1.2, pos=4)
  arrows(0, 0, vY[1], vY[2], lwd=0.7, col="red")
  text(vY[1], vY[2], labels=namesvarY, cex=1.2, pos=4, col="red")
  #COMPARAISON AU CERCLE DES CORRELATIONS DES VARIABLES X OBTENU A PARTIR DES FORMULES 'CLASSIQUES'
  #      (vecteurs propres et valeurs propres)
  #a <- seq(0, 2*pi, length=100)
  #plot(cos(a), sin(a), type='l', lty=3, xlab=paste("Composante ", x1, " (", round(res$per.var[x1], 1), "%)", sep=""), 
  #     ylab=paste("Composante ", x2, " (", round(res$per.var[x2], 1), "%)", sep=""), main="Cercle des corrélations")
  #abline(h=0, v=0)  
  #arrows(0, 0, sqrt(res$pcvar[x1])*t(res$pcload)[x1, ], sqrt(res$pcvar[x2])*t(res$pcload)[x2, ], lwd=0.7)
  #text(sqrt(res$pcvar[x1])*t(res$pcload)[x1, ], sqrt(res$pcvar[x2])*t(res$pcload)[x2, ], labels=namesvar, cex=1.2, pos=4)  
  return(res)
}
