library(HistDAWass)
Funct_mat_dist =function (x, 
                     simplify=FALSE,
                     qua=10,
                     standardize=FALSE){
  ind=nrow(x@M)
  vars=ncol(x@M)
  
  ## we homogeneize data for speeding up the code if required
  tmp=Prepare(x,simplify,qua,standardize)
  MM=tmp$MM
  x=tmp$x
  
  ##compute distance matrix
  d=matrix(0,ind,ind)
  for (i in 1:(ind-1)){
    for (j in (i+1):ind){
      for (v in 1:vars){
        tmp=ComputeFast_L2_SQ_WASS_D(cbind(MM[[v]][,i],MM[[v]][,j],MM[[v]][,(ind+1)]))
        d[i,j]= d[i,j]+tmp#WassSqDistH(x@M[i,v][[1]],x@M[j,v][[1]])
      }
      d[j,i]=d[i,j]
    }
  }
  rownames(d)=rownames(x@M)
  colnames(d)=rownames(x@M)
  return(d)
}


Prepare =function (x, simplify, qua, standardize){
  ind=nrow(x@M)
  vars=ncol(x@M)
  MM=list()
  if (simplify){
    p=(0:qua)/qua
    for (j in 1:vars){
      MM[[j]]=matrix(0,(qua+1),(ind+1))
      MM[[j]][,(ind+1)]=p
      for (i in 1:ind){
        dom=numeric(0)
        for (q in 0:qua){
          dom=c(dom, compQ(x@M[i,j][[1]],q/qua))
        }
        
        tmp=new("distributionH",dom,p) 
        tmp=(tmp-tmp@m)*(x@M[i,j][[1]]@s/tmp@s)+x@M[i,j][[1]]@m #transformation with invariance with respect mean and std
        x@M[i,j][[1]]=tmp
        MM[[j]][,i]=tmp@x
      }
    } 
  }
  else{
    
    for (j in 1:vars){
      tmp=registerMH(x[,j])
      MM[[j]]=matrix(0,length(tmp@M[1,1][[1]]@x),ind+1)
      MM[[j]][,ind+1]=tmp@M[1,1][[1]]@p
      for (i in 1:ind){
        x@M[i,j][[1]]=tmp@M[i,1][[1]]
        MM[[j]][,i]=tmp@M[i,1][[1]]@x
      }
    }
  }
  ## standardize data if required
  if (standardize){
    cat("Standardizing data...\n")
    STAND=rep(0,vars)
    Mc=rep(0,vars)
    # compute varianaces
    for (v in 1:vars){
      STAND[v]=sqrt(WH.var.covar(x[,v]))
      Mc[v]=(WH.vec.mean(x[,v]))@m
      for (i in 1:ind){
        if (STAND[v]>0){
          x@M[i,v][[1]]=new("distributionH",x=(x@M[i,v][[1]]@x-Mc[v])/STAND[v],p=x@M[i,v][[1]]@p)
          MM[[v]][,i]=(MM[[v]][,i]-Mc[v])/STAND[v]
          #x@M[i,v][[1]]@x=(x@M[i,v][[1]]@x-Mc[v])/STAND[v]
        }
      }
    }
    
  }
  return(list(MM=MM,x=x))
}
# compute fast DIST
ComputeFast_L2_SQ_WASS_D=function(subMM){
  ind=ncol(subMM)-1
  rr=nrow(subMM)
  p1=subMM[2:rr,ind+1]-subMM[1:(rr-1),ind+1]
  
  c1=(subMM[2:rr,1]+subMM[1:(rr-1),1])/2
  r1=(subMM[2:rr,1]-subMM[1:(rr-1),1])/2
  c2=(subMM[2:rr,2]+subMM[1:(rr-1),2])/2
  r2=(subMM[2:rr,2]-subMM[1:(rr-1),2])/2
  
  Dist=sum(p1*((c1-c2)^2)+ p1/3*((r1-r2)^2))
  
  return(Dist)
}